# xarray-behave

Install a working conda installation (see [here](https://docs.conda.io/en/latest/miniconda.html)). 

```shell
conda create -c conda-forge -c anaconda -c ncb -n xb python=3.9 xarray-behave
```
The GUI can be started by activating the new environment `conda activate xb` and then typing `xb` in a terminal. See `xb --help` for usage/arguments/keys.
GUI usage is documented [here](https://janclemenslab.org/das/tutorials_gui/tutorials_gui.html).

See `demo.ipynb` for usage examples.
